@@ -21,24 +21,19 @@
 #    under the License.
 
 from __future__ import absolute_import
-
 import logging
 
 from django.conf import settings
+from manilaclient import client as manila_client
 import six
 
-from manilaclient import client as manila_client
-from manilaclient.v1.contrib import list_extensions as manila_list_extensions
-
 from horizon import exceptions
-from horizon.utils.memoized import memoized  # noqa
-
 from openstack_dashboard.api import base
 
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.5"  # requires manilaclient 1.3.0 or newer
+MANILA_VERSION = "2.15"  # requires manilaclient 1.8.0 or newer
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -67,7 +62,6 @@ def manilaclient(request):
         cacert=cacert,
         http_log_debug=settings.DEBUG,
         user_agent=MANILA_UI_USER_AGENT_REPR,
-        api_version=MANILA_VERSION,
     )
     c.client.auth_token = request.user.token.id
     c.client.management_url = manila_url
@@ -110,6 +104,15 @@ def share_rules_list(request, share_id):
     return manilaclient(request).shares.access_list(share_id)
 
 
+def share_export_location_list(request, share_id):
+    return manilaclient(request).share_export_locations.list(share_id)
+
+
+def share_instance_export_location_list(request, share_instance_id):
+    return manilaclient(request).share_instance_export_locations.list(
+        share_instance_id)
+
+
 def share_allow(request, share_id, access_type, access_to, access_level):
     return manilaclient(request).shares.allow(
         share_id, access_type, access_to, access_level)
@@ -121,7 +124,7 @@ def share_deny(request, share_id, rule_id):
 
 def share_manage(request, service_host, protocol, export_path,
                  driver_options=None, share_type=None,
-                 name=None, description=None):
+                 name=None, description=None, is_public=False):
     return manilaclient(request).shares.manage(
         service_host=service_host,
         protocol=protocol,
@@ -130,6 +133,7 @@ def share_manage(request, service_host, protocol, export_path,
         share_type=share_type,
         name=name,
         description=description,
+        is_public=is_public,
     )
 
 
@@ -343,18 +347,9 @@ def tenant_absolute_limits(request):
     return limits_dict
 
 
-@memoized
-def list_extensions(request):
-    return manila_list_extensions.ListExtManager(manilaclient(request))\
-        .show_all()
+def share_instance_list(request):
+    return manilaclient(request).share_instances.list()
 
 
-@memoized
-def extension_supported(request, extension_name):
-    """This method will determine if manila supports a given extension name.
-    """
-    extensions = list_extensions(request)
-    for extension in extensions:
-        if extension.name == extension_name:
-            return True
-    return False
+def share_instance_get(request, share_instance_id):
+    return manilaclient(request).share_instances.get(share_instance_id)
