@@ -28,7 +28,7 @@ from manila_ui.dashboards.project.shares.snapshots \
 
 
 def get_size(share):
-    return _("%sGB") % share.size
+    return _("%sGiB") % share.size
 
 
 class CreateShareType(tables.LinkAction):
@@ -154,10 +154,10 @@ class SharesTable(shares_tables.SharesTable):
                          verbose_name=_("Name"),
                          link="horizon:admin:shares:detail")
     host = tables.Column("host", verbose_name=_("Host"))
-    tenant = tables.Column("tenant_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
 
     def get_share_server_link(share):
-        if hasattr(share, 'share_server_id'):
+        if getattr(share, 'share_server_id', None):
             return reverse("horizon:admin:shares:share_server_detail",
                            args=(share.share_server_id,))
         else:
@@ -298,7 +298,7 @@ class SecurityServiceTable(tables.DataTable):
     name = tables.Column("name",
                          verbose_name=_("Name"),
                          link="horizon:admin:shares:security_service_detail")
-    tenant = tables.Column("tenant_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
     dns_ip = tables.Column("dns_ip", verbose_name=_("DNS IP"))
     server = tables.Column("server", verbose_name=_("Server"))
     domain = tables.Column("domain", verbose_name=_("Domain"))
@@ -329,7 +329,7 @@ class NovaShareNetworkTable(tables.DataTable):
     name = tables.Column("name",
                          verbose_name=_("Name"),
                          link="horizon:admin:shares:share_network_detail")
-    tenant = tables.Column("tenant_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
     nova_net = tables.Column("nova_net", verbose_name=_("Nova Net"))
     ip_version = tables.Column("ip_version", verbose_name=_("IP Version"))
     network_type = tables.Column("network_type",
@@ -354,7 +354,7 @@ class NovaShareNetworkTable(tables.DataTable):
 class NeutronShareNetworkTable(tables.DataTable):
     name = tables.Column("name", verbose_name=_("Name"),
                          link="horizon:project:shares:share_network_detail")
-    tenant = tables.Column("tenant_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
     neutron_net = tables.Column("neutron_net", verbose_name=_("Neutron Net"))
     neutron_subnet = tables.Column(
         "neutron_subnet", verbose_name=_("Neutron Subnet"))
@@ -405,7 +405,7 @@ class ShareServerTable(tables.DataTable):
     uid = tables.Column("id", verbose_name=_("Id"),
                         link="horizon:admin:shares:share_server_detail")
     host = tables.Column("host", verbose_name=_("Host"))
-    tenant = tables.Column("tenant_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
 
     def get_share_server_link(share_serv):
         if hasattr(share_serv, 'share_network_id'):
@@ -435,3 +435,78 @@ class ShareServerTable(tables.DataTable):
         table_actions = (DeleteShareServer, SharesServersFilterAction)
         row_class = UpdateShareServerRow
         row_actions = (DeleteShareServer, )
+
+
+class ShareInstancesTable(tables.DataTable):
+    STATUS_CHOICES = (
+        ("available", True),
+        ("creating", None),
+        ("deleting", None),
+        ("error", False),
+        ("error_deleting", False),
+    )
+    STATUS_DISPLAY_CHOICES = (
+        ("available", u"Available"),
+        ("creating", u"Creating"),
+        ("deleting", u"Deleting"),
+        ("error", u"Error"),
+        ("error_deleting", u"Error deleting"),
+    )
+    uuid = tables.Column(
+        "id", verbose_name=_("ID"),
+        link="horizon:admin:shares:share_instance_detail")
+    host = tables.Column("host", verbose_name=_("Host"))
+    status = tables.Column("status",
+                           verbose_name=_("Status"),
+                           status=True,
+                           status_choices=STATUS_CHOICES,
+                           display_choices=STATUS_DISPLAY_CHOICES)
+    availability_zone = tables.Column(
+        "availability_zone", verbose_name=_("Availability Zone"))
+
+    class Meta(object):
+        name = "share_instances"
+        verbose_name = _("Share Instances")
+        status_columns = ("status", )
+        table_actions = (shares_tables.SharesFilterAction, )
+        multi_select = False
+
+    def get_share_network_link(share_instance):
+        if getattr(share_instance, 'share_network_id', None):
+            return reverse("horizon:admin:shares:share_network_detail",
+                           args=(share_instance.share_network_id,))
+        else:
+            return None
+
+    def get_share_server_link(share_instance):
+        if getattr(share_instance, 'share_server_id', None):
+            return reverse("horizon:admin:shares:share_server_detail",
+                           args=(share_instance.share_server_id,))
+        else:
+            return None
+
+    def get_share_link(share_instance):
+        if getattr(share_instance, 'share_id', None):
+            return reverse("horizon:project:shares:detail",
+                           args=(share_instance.share_id,))
+        else:
+            return None
+
+    share_net_id = tables.Column(
+        "share_network_id",
+        verbose_name=_("Share Network"),
+        link=get_share_network_link)
+    share_server_id = tables.Column(
+        "share_server_id",
+        verbose_name=_("Share Server Id"),
+        link=get_share_server_link)
+    share_id = tables.Column(
+        "share_id",
+        verbose_name=_("Share ID"),
+        link=get_share_link)
+
+    def get_object_display(self, share_instance):
+        return six.text_type(share_instance.id)
+
+    def get_object_id(self, share_instance):
+        return six.text_type(share_instance.id)
