@@ -58,6 +58,14 @@ class DetailView(tabs.TabView):
     tab_group_class = shares_tabs.ShareDetailTabs
     template_name = 'project/shares/shares/detail.html'
 
+    def _calculate_size_of_longest_export_location(self, export_locations):
+        size = 40
+        for export_location in export_locations:
+            current_size = len(export_location["path"])
+            if current_size > size:
+                size = current_size
+        return size
+
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
         share = self.get_data()
@@ -75,6 +83,10 @@ class DetailView(tabs.TabView):
             share_id = self.kwargs['share_id']
             share = manila.share_get(self.request, share_id)
             share.rules = manila.share_rules_list(self.request, share_id)
+            share.export_locations = manila.share_export_location_list(
+                self.request, share_id)
+            share.el_size = self._calculate_size_of_longest_export_location(
+                share.export_locations)
         except Exception:
             redirect = reverse('horizon:project:shares:index')
             exceptions.handle(self.request,
@@ -216,3 +228,40 @@ class ManageRulesView(tables.DataTableView):
                               _('Unable to retrieve share rules.'),
                               redirect=redirect)
         return rules
+
+
+class ExtendView(forms.ModalFormView):
+    form_class = share_form.ExtendForm
+    template_name = 'project/shares/shares/extend.html'
+    success_url = reverse_lazy("horizon:project:shares:index")
+    page_title = _('Extend Share')
+
+    def get_object(self):
+        if not hasattr(self, "_object"):
+            share_id = self.kwargs['share_id']
+            try:
+                self._object = manila.share_get(self.request, share_id)
+            except Exception:
+                msg = _('Unable to retrieve share.')
+                url = reverse('horizon:project:shares:index')
+                exceptions.handle(self.request, msg, redirect=url)
+        return self._object
+
+    def get_context_data(self, **kwargs):
+        context = super(ExtendView, self).get_context_data(**kwargs)
+        context['share'] = self.get_object()
+
+        try:
+            context['usages'] = quotas.tenant_limit_usages(self.request)
+        except Exception:
+            exceptions.handle(self.request)
+
+        return context
+
+    def get_initial(self):
+        share = self.get_object()
+        return {'share_id': self.kwargs["share_id"],
+                'name': share.name,
+                'orig_size': share.size,
+                'new_size': int(share.size) + 1
+                }
